==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/ActivitypointerCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.FunctionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Integer;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.complex.RetrieveTimelineWallRecordsResponse;
import microsoft.dynamics.crm.entity.Activitypointer;
import microsoft.dynamics.crm.entity.Crmbaseentity;
import microsoft.dynamics.crm.entity.request.ActivitymimeattachmentRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.ActivitypointerRequest;
import microsoft.dynamics.crm.entity.request.AppointmentRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.EmailRequest;
import microsoft.dynamics.crm.entity.request.FaxRequest;
import microsoft.dynamics.crm.entity.request.LetterRequest;
import microsoft.dynamics.crm.entity.request.PhonecallRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.RecurrenceruleRequest;
import microsoft.dynamics.crm.entity.request.RecurringappointmentmasterRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SocialactivityRequest;
import microsoft.dynamics.crm.entity.request.TaskRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class ActivitypointerCollectionRequest extends CollectionPageEntityRequest<Activitypointer, ActivitypointerRequest>{

    protected ContextPath contextPath;

    public ActivitypointerCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Activitypointer.class, cp -> new ActivitypointerRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SocialactivityCollectionRequest activity_pointer_socialactivity() {
        return new SocialactivityCollectionRequest(contextPath.addSegment("activity_pointer_socialactivity"), Optional.empty());
    }

    public SocialactivityRequest activity_pointer_socialactivity(String activityid) {
        return new SocialactivityRequest(contextPath.addSegment("activity_pointer_socialactivity").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public RecurringappointmentmasterCollectionRequest activity_pointer_recurringappointmentmaster() {
        return new RecurringappointmentmasterCollectionRequest(contextPath.addSegment("activity_pointer_recurringappointmentmaster"), Optional.empty());
    }

    public RecurringappointmentmasterRequest activity_pointer_recurringappointmentmaster(String activityid) {
        return new RecurringappointmentmasterRequest(contextPath.addSegment("activity_pointer_recurringappointmentmaster").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public EmailCollectionRequest activity_pointer_email() {
        return new EmailCollectionRequest(contextPath.addSegment("activity_pointer_email"), Optional.empty());
    }

    public EmailRequest activity_pointer_email(String activityid) {
        return new EmailRequest(contextPath.addSegment("activity_pointer_email").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest activityPointer_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("ActivityPointer_QueueItem"), Optional.empty());
    }

    public QueueitemRequest activityPointer_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("ActivityPointer_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public ActivitymimeattachmentCollectionRequest activity_pointer_activity_mime_attachment() {
        return new ActivitymimeattachmentCollectionRequest(contextPath.addSegment("activity_pointer_activity_mime_attachment"), Optional.empty());
    }

    public ActivitymimeattachmentRequest activity_pointer_activity_mime_attachment(String activitymimeattachmentid) {
        return new ActivitymimeattachmentRequest(contextPath.addSegment("activity_pointer_activity_mime_attachment").addKeys(new NameValue(activitymimeattachmentid.toString())), Optional.empty());
    }

    public FaxCollectionRequest activity_pointer_fax() {
        return new FaxCollectionRequest(contextPath.addSegment("activity_pointer_fax"), Optional.empty());
    }

    public FaxRequest activity_pointer_fax(String activityid) {
        return new FaxRequest(contextPath.addSegment("activity_pointer_fax").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public TaskCollectionRequest activity_pointer_task() {
        return new TaskCollectionRequest(contextPath.addSegment("activity_pointer_task"), Optional.empty());
    }

    public TaskRequest activity_pointer_task(String activityid) {
        return new TaskRequest(contextPath.addSegment("activity_pointer_task").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public PhonecallCollectionRequest activity_pointer_phonecall() {
        return new PhonecallCollectionRequest(contextPath.addSegment("activity_pointer_phonecall"), Optional.empty());
    }

    public PhonecallRequest activity_pointer_phonecall(String activityid) {
        return new PhonecallRequest(contextPath.addSegment("activity_pointer_phonecall").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public AppointmentCollectionRequest activity_pointer_appointment() {
        return new AppointmentCollectionRequest(contextPath.addSegment("activity_pointer_appointment"), Optional.empty());
    }

    public AppointmentRequest activity_pointer_appointment(String activityid) {
        return new AppointmentRequest(contextPath.addSegment("activity_pointer_appointment").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public LetterCollectionRequest activity_pointer_letter() {
        return new LetterCollectionRequest(contextPath.addSegment("activity_pointer_letter"), Optional.empty());
    }

    public LetterRequest activity_pointer_letter(String activityid) {
        return new LetterRequest(contextPath.addSegment("activity_pointer_letter").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest activitypointer_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("activitypointer_connections2"), Optional.empty());
    }

    public ConnectionRequest activitypointer_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("activitypointer_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_activitypointer() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_activitypointer"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_activitypointer(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_activitypointer").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest activityPointer_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("ActivityPointer_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest activityPointer_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("ActivityPointer_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest activitypointer_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("activitypointer_connections1"), Optional.empty());
    }

    public ConnectionRequest activitypointer_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("activitypointer_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest activityPointer_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("ActivityPointer_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest activityPointer_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("ActivityPointer_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public RecurrenceruleCollectionRequest activity_pointer_recurrencerule() {
        return new RecurrenceruleCollectionRequest(contextPath.addSegment("activity_pointer_recurrencerule"), Optional.empty());
    }

    public RecurrenceruleRequest activity_pointer_recurrencerule(String ruleid) {
        return new RecurrenceruleRequest(contextPath.addSegment("activity_pointer_recurrencerule").addKeys(new NameValue(ruleid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest activitypointer_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("activitypointer_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest activitypointer_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("activitypointer_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveTimelineWallRecords")
    @JsonIgnore
    public FunctionRequestReturningNonCollectionUnwrapped<RetrieveTimelineWallRecordsResponse> retrieveTimelineWallRecords(String fetchXml, Crmbaseentity target, Integer rollupType) {
        Preconditions.checkNotNull(fetchXml, "fetchXml cannot be null");
        Preconditions.checkNotNull(target, "target cannot be null");
        Preconditions.checkNotNull(rollupType, "rollupType cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("FetchXml", "Edm.String", Checks.checkIsAscii(fetchXml))
            .put("Target", "Microsoft.Dynamics.CRM.crmbaseentity", target)
            .put("RollupType", "Edm.Int32", rollupType)
            .build();
        return new FunctionRequestReturningNonCollectionUnwrapped<RetrieveTimelineWallRecordsResponse>(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveTimelineWallRecords"), RetrieveTimelineWallRecordsResponse.class, _parameters, microsoft.dynamics.crm.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/ActivitypointerCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.FunctionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Function;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Integer;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import microsoft.dynamics.crm.complex.RetrieveTimelineWallRecordsResponse;
import microsoft.dynamics.crm.entity.Activitypointer;
import microsoft.dynamics.crm.entity.Crmbaseentity;
import microsoft.dynamics.crm.entity.request.ActivitymimeattachmentRequest;
import microsoft.dynamics.crm.entity.request.ActivitypartyRequest;
import microsoft.dynamics.crm.entity.request.ActivitypointerRequest;
import microsoft.dynamics.crm.entity.request.AppointmentRequest;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.EmailRequest;
import microsoft.dynamics.crm.entity.request.FaxRequest;
import microsoft.dynamics.crm.entity.request.LetterRequest;
import microsoft.dynamics.crm.entity.request.PhonecallRequest;
import microsoft.dynamics.crm.entity.request.QueueitemRequest;
import microsoft.dynamics.crm.entity.request.RecurrenceruleRequest;
import microsoft.dynamics.crm.entity.request.RecurringappointmentmasterRequest;
import microsoft.dynamics.crm.entity.request.SlakpiinstanceRequest;
import microsoft.dynamics.crm.entity.request.SocialactivityRequest;
import microsoft.dynamics.crm.entity.request.TaskRequest;

public class ActivitypointerCollectionRequest extends CollectionPageEntityRequest<Activitypointer, ActivitypointerRequest>{

    protected ContextPath contextPath;

    public ActivitypointerCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Activitypointer.class, cp -> new ActivitypointerRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SocialactivityCollectionRequest activity_pointer_socialactivity() {
        return new SocialactivityCollectionRequest(contextPath.addSegment("activity_pointer_socialactivity"), Optional.empty());
    }

    public SocialactivityRequest activity_pointer_socialactivity(String activityid) {
        return new SocialactivityRequest(contextPath.addSegment("activity_pointer_socialactivity").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public RecurringappointmentmasterCollectionRequest activity_pointer_recurringappointmentmaster() {
        return new RecurringappointmentmasterCollectionRequest(contextPath.addSegment("activity_pointer_recurringappointmentmaster"), Optional.empty());
    }

    public RecurringappointmentmasterRequest activity_pointer_recurringappointmentmaster(String activityid) {
        return new RecurringappointmentmasterRequest(contextPath.addSegment("activity_pointer_recurringappointmentmaster").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public EmailCollectionRequest activity_pointer_email() {
        return new EmailCollectionRequest(contextPath.addSegment("activity_pointer_email"), Optional.empty());
    }

    public EmailRequest activity_pointer_email(String activityid) {
        return new EmailRequest(contextPath.addSegment("activity_pointer_email").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public QueueitemCollectionRequest activityPointer_QueueItem() {
        return new QueueitemCollectionRequest(contextPath.addSegment("ActivityPointer_QueueItem"), Optional.empty());
    }

    public QueueitemRequest activityPointer_QueueItem(String queueitemid) {
        return new QueueitemRequest(contextPath.addSegment("ActivityPointer_QueueItem").addKeys(new NameValue(queueitemid.toString())), Optional.empty());
    }

    public ActivitymimeattachmentCollectionRequest activity_pointer_activity_mime_attachment() {
        return new ActivitymimeattachmentCollectionRequest(contextPath.addSegment("activity_pointer_activity_mime_attachment"), Optional.empty());
    }

    public ActivitymimeattachmentRequest activity_pointer_activity_mime_attachment(String activitymimeattachmentid) {
        return new ActivitymimeattachmentRequest(contextPath.addSegment("activity_pointer_activity_mime_attachment").addKeys(new NameValue(activitymimeattachmentid.toString())), Optional.empty());
    }

    public FaxCollectionRequest activity_pointer_fax() {
        return new FaxCollectionRequest(contextPath.addSegment("activity_pointer_fax"), Optional.empty());
    }

    public FaxRequest activity_pointer_fax(String activityid) {
        return new FaxRequest(contextPath.addSegment("activity_pointer_fax").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public TaskCollectionRequest activity_pointer_task() {
        return new TaskCollectionRequest(contextPath.addSegment("activity_pointer_task"), Optional.empty());
    }

    public TaskRequest activity_pointer_task(String activityid) {
        return new TaskRequest(contextPath.addSegment("activity_pointer_task").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public PhonecallCollectionRequest activity_pointer_phonecall() {
        return new PhonecallCollectionRequest(contextPath.addSegment("activity_pointer_phonecall"), Optional.empty());
    }

    public PhonecallRequest activity_pointer_phonecall(String activityid) {
        return new PhonecallRequest(contextPath.addSegment("activity_pointer_phonecall").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public AppointmentCollectionRequest activity_pointer_appointment() {
        return new AppointmentCollectionRequest(contextPath.addSegment("activity_pointer_appointment"), Optional.empty());
    }

    public AppointmentRequest activity_pointer_appointment(String activityid) {
        return new AppointmentRequest(contextPath.addSegment("activity_pointer_appointment").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public LetterCollectionRequest activity_pointer_letter() {
        return new LetterCollectionRequest(contextPath.addSegment("activity_pointer_letter"), Optional.empty());
    }

    public LetterRequest activity_pointer_letter(String activityid) {
        return new LetterRequest(contextPath.addSegment("activity_pointer_letter").addKeys(new NameValue(activityid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest activitypointer_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("activitypointer_connections2"), Optional.empty());
    }

    public ConnectionRequest activitypointer_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("activitypointer_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public SlakpiinstanceCollectionRequest slakpiinstance_activitypointer() {
        return new SlakpiinstanceCollectionRequest(contextPath.addSegment("slakpiinstance_activitypointer"), Optional.empty());
    }

    public SlakpiinstanceRequest slakpiinstance_activitypointer(String slakpiinstanceid) {
        return new SlakpiinstanceRequest(contextPath.addSegment("slakpiinstance_activitypointer").addKeys(new NameValue(slakpiinstanceid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest activityPointer_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("ActivityPointer_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest activityPointer_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("ActivityPointer_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest activitypointer_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("activitypointer_connections1"), Optional.empty());
    }

    public ConnectionRequest activitypointer_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("activitypointer_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest activityPointer_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("ActivityPointer_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest activityPointer_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("ActivityPointer_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public RecurrenceruleCollectionRequest activity_pointer_recurrencerule() {
        return new RecurrenceruleCollectionRequest(contextPath.addSegment("activity_pointer_recurrencerule"), Optional.empty());
    }

    public RecurrenceruleRequest activity_pointer_recurrencerule(String ruleid) {
        return new RecurrenceruleRequest(contextPath.addSegment("activity_pointer_recurrencerule").addKeys(new NameValue(ruleid.toString())), Optional.empty());
    }

    public ActivitypartyCollectionRequest activitypointer_activity_parties() {
        return new ActivitypartyCollectionRequest(contextPath.addSegment("activitypointer_activity_parties"), Optional.empty());
    }

    public ActivitypartyRequest activitypointer_activity_parties(String activitypartyid) {
        return new ActivitypartyRequest(contextPath.addSegment("activitypointer_activity_parties").addKeys(new NameValue(activitypartyid.toString())), Optional.empty());
    }

    @Function(name = "RetrieveTimelineWallRecords")
    @JsonIgnore
    public FunctionRequestReturningNonCollectionUnwrapped<RetrieveTimelineWallRecordsResponse> retrieveTimelineWallRecords(String fetchXml, Crmbaseentity target, Integer rollupType) {
        Preconditions.checkNotNull(fetchXml, "fetchXml cannot be null");
        Preconditions.checkNotNull(target, "target cannot be null");
        Preconditions.checkNotNull(rollupType, "rollupType cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("FetchXml", "Edm.String", Checks.checkIsAscii(fetchXml))
            .put("Target", "Microsoft.Dynamics.CRM.crmbaseentity", target)
            .put("RollupType", "Edm.Int32", rollupType)
            .build();
        return new FunctionRequestReturningNonCollectionUnwrapped<RetrieveTimelineWallRecordsResponse>(this.contextPath.addActionOrFunctionSegment("Microsoft.Dynamics.CRM.RetrieveTimelineWallRecords"), RetrieveTimelineWallRecordsResponse.class, _parameters);
    }

}
